@@ -16,15 +16,19 @@ package sanitize // import "github.com/open-telemetry/opentelemetry-collector-co
 
 import (
 	"net/url"
-	"regexp"
-)
-
-var (
-	carriageReturnOrLineFeedRegexp = regexp.MustCompile(`\n|\r`)
+	"strings"
 )
 
 // URL removes control characters from the URL parameter. This addresses CWE-117:
 // https://cwe.mitre.org/data/definitions/117.html
 func URL(unsanitized *url.URL) string {
-	return carriageReturnOrLineFeedRegexp.ReplaceAllString(unsanitized.String(), "")
+	escaped := strings.Replace(unsanitized.String(), "\n", "", -1)
+	return strings.Replace(escaped, "\r", "", -1)
+}
+
+// String removes control characters from String parameter. This addresses CWE-117:
+// https://cwe.mitre.org/data/definitions/117.html
+func String(unsanitized string) string {
+	escaped := strings.Replace(unsanitized, "\n", "", -1)
+	return strings.Replace(escaped, "\r", "", -1)
 }
